@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
-version: 4.7.5.2
-id: hakyll-4.7.5.2-8b0a839c624842be5b81f40d555bf92a
-key: hakyl_9or52Tu8mQ73uYsA2uxP1D
+version: 4.8.3.0
+id: hakyll-4.8.3.0-64cf2972080346c1cf61367bd93b3a76
+key: hakyl_7pyFEvOWjZ80tsi5cBH26x
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -39,48 +39,53 @@ exposed-modules:
     Hakyll.Web.Paginate Hakyll.Web.Template
     Hakyll.Web.Template.Internal Hakyll.Web.Template.Context
     Hakyll.Web.Template.List
-hidden-modules: Hakyll.Check Hakyll.Commands
-                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
-                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
+hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
+                Hakyll.Commands Hakyll.Core.Compiler.Internal
+                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
+                Hakyll.Core.Logger Hakyll.Core.Provider
                 Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                 Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                 Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                 Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.2
-hs-libraries: HShakyll-4.7.5.2-9or52Tu8mQ73uYsA2uxP1D
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.8.3.0
+hs-libraries: HShakyll-4.8.3.0-7pyFEvOWjZ80tsi5cBH26x
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lrucache-1.2.0.0-fe7339ef35e8dfe001bb854bdca651f6
+    http-conduit-2.1.10.1-06d6cae4a7dc7e652455c24a41eb9def
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    lrucache-1.2.0.0-f6a00c6545b50474cbf44906f698e532
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    pandoc-1.17.0.3-eb510c613bb58261320cda2a21b65c87
-    pandoc-citeproc-0.9.1.1-549a0472ef347a7ec97a56008c4d2d94
+    pandoc-1.17.0.3-45381fe983c6bd3cb90c0ba87bbc9082
+    pandoc-citeproc-0.9.1.1-5d34ad48004833484b402d29858f377a
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
-    regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
-    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
+    regex-tdfa-1.2.2-356f1fd0d011fc4d4ac3ea6a1e65b0ca
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
+    tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
+    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
+    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
 haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
 haddock-html: /usr/share/doc/haskell-hakyll/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
